spoon.objTypes

Package spoon :: Module objTypes |
[hide private]
[frames] | no frames]

# Source Code for Module spoon.objTypes

     1  #
     2  # Copyright (C) 2006, Matt Sullivan <matts@zarrf.com>
     3  #
     4  # Permission is hereby granted, free of charge, to any person obtaining
     5  # a copy of this software and associated documentation files (the
     6  # "Software"), to deal in the Software without restriction, including
     7  # without limitation the rights to use, copy, modify, merge, publish,
     8  # distribute, sublicense, and/or sell copies of the Software, and to
     9  # permit persons to whom the Software is furnished to do so, subject to
    10  # the following conditions:
    11  #
    12  # The above copyright notice and this permission notice shall be included
    13  # in all copies or substantial portions of the Software.
    14  #
    15  # THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
    16  # OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
    17  # MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
    18  # IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
    19  # CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
    20  # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
    21  # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
    22  #
    23
    24  # For simplicity's sake, LMTYPE_INIT will be handled specially without the need for an explicit handler
    25  # in the transport.
    26  LMTYPE_INIT = 0
    27  # LMTYPE_NETWORK is a message for the networking system associated with a transport.
    28  LMTYPE_NETWORK = 1
    29  # LMTYPE_NETWORK_PROTO is a protocol message for the networking system associated with the transport.
    30  # For example a MeshRouter hop count update message would be sent with this type.
    31  LMTYPE_NETWORK_PROTO = 2
    32
    33
    34  # NetMessage type for the Messaging system
    35  NMTYPE_MESSAGING = 0
    36